==> kafka-3.9.0-src.tgz: kafka-3.9.0-src/streams/src/main/java/org/apache/kafka/streams/errors/InvalidStateStoreException.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements. See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.kafka.streams.errors;


/**
 * Indicates that there was a problem when trying to access a {@link org.apache.kafka.streams.processor.StateStore StateStore}.
 * {@code InvalidStateStoreException} is not thrown directly but only its following sub-classes.
 */
public class InvalidStateStoreException extends StreamsException {

    private static final long serialVersionUID = 1L;

    public InvalidStateStoreException(final String message) {
        super(message);
    }

    public InvalidStateStoreException(final String message, final Throwable throwable) {
        super(message, throwable);
    }

    public InvalidStateStoreException(final Throwable throwable) {
        super(throwable);
    }
}

==> kafka-4.0.0-src.tgz: kafka-4.0.0-src/streams/src/main/java/org/apache/kafka/streams/errors/InvalidStateStoreException.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements. See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.kafka.streams.errors;

/**
 * Indicates that there was a problem when trying to access a {@link org.apache.kafka.streams.processor.StateStore StateStore}.
 * {@code InvalidStateStoreException} is not thrown directly but only its following subclasses.
 */
public class InvalidStateStoreException extends StreamsException {

    private static final long serialVersionUID = 1L;

    public InvalidStateStoreException(final String message) {
        super(message);
    }

    public InvalidStateStoreException(final String message, final Throwable throwable) {
        super(message, throwable);
    }

    public InvalidStateStoreException(final Throwable throwable) {
        super(throwable);
    }
}
